/* 
 * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef _STUB_CONTAINER_H_
#define _STUB_CONTAINER_H_

#include "stub_view.h"

namespace mforms { namespace stub
{  
  class ContainerWrapper : public ViewWrapper
  {
  protected:
    ContainerWrapper(::mforms::View *self)
      : ViewWrapper(self)
    {
    }

    void add(::mforms::View *child)
    {
    }

    void remove()
    {
    }

    void remove(::mforms::View *child)
    {
    }
  };
  
}; };

#endif // _STUB_CONTAINER_H_
